# -*- coding: utf-8 -*-
from django.contrib import admin
from .models import (
    Application,
    BusinessUnit,
    Category,
    ContractType,
    JobOffer,
    Sector,
)
from django import forms


@admin.register(ContractType)
class ContractTypeAdmin(admin.ModelAdmin):
    """Contract type for Job offers"""
    pass


@admin.register(JobOffer)
class JobOfferAdmin(admin.ModelAdmin):
    """Job offers"""
    search_fields = [
        'title',
        'reference',
        'country',
    ]
    list_filter = [
        'date',
        'geo_area',
    ]
    list_display = [
        '__unicode__',
        'reference',
        'location',
    ]
    prepopulated_fields = {
        'slug': ['title']
    }


@admin.register(Category)
class CategoryAdmin(admin.ModelAdmin):
    """Category"""
    pass


@admin.register(Sector)
class SectorAdmin(admin.ModelAdmin):
    pass


@admin.register(BusinessUnit)
class BusinessUnitAdmin(admin.ModelAdmin):
    pass


class ApplicationModelForm(forms.ModelForm):
    """Forms for Application"""
    message = forms.CharField(
        widget=forms.Textarea
    )

    class Meta:
        model = Application
        fields = [
            'job_offer',
            'message',
            'last_name',
            'first_name',
            'email',
            'phone',
            'cv',
            'cover_letter',
            'other_document',
        ]


@admin.register(Application)
class ApplicationAdmin(admin.ModelAdmin):
    """Job application"""
    form = ApplicationModelForm

    search_fields = [
        'last_name',
        'email',
        'phone',
    ]
    list_filter = [
        'date',
        'job_offer__location',
        'job_offer__geo_area',
    ]
    list_display = [
        '__unicode__',
        'last_name',
        'email',
        'job_location',
        'job_area',
        'get_cv',
    ]

    def job_area(self, obj):
        return obj.job_offer.geo_area

    def job_location(self, obj):
        return obj.job_offer.location

    def get_cv(self, obj):
        return '<a href="%s">%s</a>' % (obj.cv.url, obj.last_name + ' cv')

    get_cv.allow_tags = True
    get_cv.short_description = "Cv"
