# -*- coding: utf-8 -*-

from django.core.mail import EmailMessage
from django.conf import settings
from django.template.loader import render_to_string


class BaseMail(object):
    subject_template = None
    body_template = None

    def __init__(self, subject_template=None, body_template=None):
        self.subject_template = subject_template or self.__class__.subject_template
        self.body_template = body_template or self.__class__.body_template

    def get_email(self, application):
        raise NotImplementedError

    def render_subject(self, context):
        return render_to_string(self.subject_template, context).replace(u'\n', u' ')

    def render_body(self, context):
        return render_to_string(self.body_template, context)


class BaseCandidateConfirmationMail(BaseMail):
    def get_email(self, application):
        # mail
        context = {
            'application': application,
        }
        return EmailMessage(
            self.render_subject(context),
            self.render_body(context),
            settings.JOB_OFFER_FROM_EMAIL,
            [application.email],
        )


class SpecApplicationConfirmationMail(BaseCandidateConfirmationMail):
    subject_template = 'job_offers/mails/job-offer-confirmation-subject.txt'
    body_template = 'job_offers/mails/job-offer-confirmation-body.txt'


class JobOfferConfirmationMail(BaseCandidateConfirmationMail):
    subject_template = 'job_offers/mails/speculative-application-confirmation-subject.txt'
    body_template = 'job_offers/mails/speculative-application-confirmation-body.txt'


class AdminNotificationMail(BaseMail):
    subject_template = 'job_offers/mails/admin-notification-subject.txt'
    body_template = 'job_offers/mails/admin-notification-body.txt'

    def get_email(self, application):
        # Admin mail
        context = {
            'application': application,
        }

        mail = EmailMessage(
            self.render_subject(context),
            self.render_body(context),
            settings.JOB_OFFER_FROM_EMAIL,
            settings.JOB_OFFER_ADMIN_EMAILS,
        )
        mail.attach(application.cv.name, application.cv.read())
        return mail
